==> phoenix-starter-rosefinch-0.2.0.2-20241015.063846-1-sources.jar: com/elitesland/cbpl/rosefinch/proxy/ProducerProxyService.java <==
package com.elitesland.cbpl.rosefinch.proxy;

import com.elitesland.cbpl.common.constant.SuccessTag;
import com.elitesland.cbpl.logging.syslog.util.LogUtil;
import com.elitesland.cbpl.rosefinch.client.constant.RosefinchType;
import com.elitesland.cbpl.rosefinch.client.queue.producer.ProducerProxy;
import com.elitesland.cbpl.rosefinch.client.queue.producer.message.TaskMessage;
import com.elitesland.cbpl.rosefinch.common.constant.InstanceStatus;
import com.elitesland.cbpl.rosefinch.data.convert.RosefinchConfigConvert;
import com.elitesland.cbpl.rosefinch.data.service.RosefinchInstanceService;
import com.elitesland.cbpl.rosefinch.data.vo.param.RosefinchInstanceSaveParamVO;
import com.elitesland.cbpl.rosefinch.queue.QueueHandlerService;
import com.elitesland.cbpl.rosefinch.util.RosefinchTraceUtil;
import com.elitesland.cbpl.tool.core.bean.BeanUtils;
import com.elitesland.cbpl.unicom.annotation.UnicomTag;
import com.elitesland.cbpl.unicom.domain.InvokeTag;
import com.lzhpo.tracer.util.TracerUtils;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;

import java.time.LocalDateTime;

import static com.elitesland.cbpl.rosefinch.util.RosefinchUtil.instanceKey;

/**
 * @author eric.hao
 * @since 2024/10/08
 */
@Slf4j
@UnicomTag(InvokeTag.TAG_GENERAL)
@RequiredArgsConstructor
public class ProducerProxyService implements ProducerProxy {

    private final RosefinchInstanceService instanceService;
    private final QueueHandlerService handlerService;

    @Override
    public Long send(TaskMessage<?> payload, String runType) {
        // 初始化任务链路ID
        RosefinchTraceUtil.initTraceId();
        // 初始化任务日志
        var instance = instanceLog(payload, runType);
        payload.setInstanceDTO(RosefinchConfigConvert.INSTANCE.saveParamToDTO(instance));
        // 生产者：发布报文消息
        handlerService.publish(payload);
        // 销毁任务链路ID
        RosefinchTraceUtil.clearTraceId();
        return instance.getId();
    }

    @Override
    public boolean stop(String taskCode, long instanceId) {
        try {
            LogUtil.info(taskCode, null, "[ROSEFINCH] 终止任务...", null, null);
            // 立即终止
            boolean stopTag = handlerService.stopImmediately(instanceKey(instanceId));
            // 更新执行结果
            var saveParam = new RosefinchInstanceSaveParamVO();
            saveParam.setId(instanceId);
            saveParam.setEndTime(LocalDateTime.now());
            if (stopTag) {
                saveParam.setInstanceStatus(InstanceStatus.STOP.getCode());
            }
            saveParam.setRemark("手动终止：" + SuccessTag.fromCode(stopTag));
            instanceService.update(saveParam);
            LogUtil.info(taskCode, null, "[ROSEFINCH] 终止任务：" + SuccessTag.fromCode(stopTag), null, null);
            return stopTag;
        } catch (Exception e) {
            logger.error("[ROSEFINCH] 终止任务异常：", e);
            LogUtil.error("[ROSEFINCH] 终止任务异常：", e);
            // 终止异常，按失败返回
            return false;
        }
    }

    /**
     * 实例日志初始化
     *
     * @param payload 消息报文
     * @param runType 执行方式
     * @return 任务实例
     */
    private RosefinchInstanceSaveParamVO instanceLog(TaskMessage<?> payload, String runType) {
        var saveParam = new RosefinchInstanceSaveParamVO();
        saveParam.setMasId(payload.getTaskId());
        saveParam.setTaskName(payload.getTaskName());
        saveParam.setTaskCode(payload.getTaskCode());
        saveParam.setRunType(runType);
        saveParam.setInstanceStatus(InstanceStatus.READY.getCode());
        saveParam.setStartTime(LocalDateTime.now());
        saveParam.setGlobalTraceId(TracerUtils.getTraceId());
        saveParam.setTraceId(RosefinchTraceUtil.getTraceId());
        saveParam.setMethodArgs(BeanUtils.toJsonOrEmpty(payload.getPayload()));
        // 批处理任务
        if (RosefinchType.BATCH.getCode().compareTo(payload.getTaskType()) == 0) {
            saveParam.setTotalCount(payload.size());
            saveParam.setSuccessCount(0);
            saveParam.setFailCount(0);
        }
        Long instanceId = instanceService.save(saveParam);
        saveParam.setId(instanceId);
        return saveParam;
    }
}

==> phoenix-starter-rosefinch-0.2.1.1-20241221.075408-1-sources.jar: com/elitesland/cbpl/rosefinch/proxy/ProducerProxyService.java <==
package com.elitesland.cbpl.rosefinch.proxy;

import com.elitesland.cbpl.common.constant.SuccessTag;
import com.elitesland.cbpl.logging.syslog.util.LogUtil;
import com.elitesland.cbpl.rosefinch.client.constant.RosefinchType;
import com.elitesland.cbpl.rosefinch.client.queue.producer.ProducerProxy;
import com.elitesland.cbpl.rosefinch.client.queue.producer.message.TaskMessage;
import com.elitesland.cbpl.rosefinch.common.constant.InstanceStatus;
import com.elitesland.cbpl.rosefinch.data.convert.RosefinchConfigConvert;
import com.elitesland.cbpl.rosefinch.data.service.RosefinchInstanceService;
import com.elitesland.cbpl.rosefinch.data.vo.param.RosefinchInstanceSaveParamVO;
import com.elitesland.cbpl.rosefinch.queue.QueueHandlerService;
import com.elitesland.cbpl.rosefinch.util.RosefinchTraceUtil;
import com.elitesland.cbpl.tool.core.bean.BeanUtils;
import com.elitesland.cbpl.unicom.annotation.UnicomTag;
import com.elitesland.cbpl.unicom.domain.InvokeTag;
import com.lzhpo.tracer.util.TracerUtils;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;

import static com.elitesland.cbpl.rosefinch.util.RosefinchUtil.instanceKey;

/**
 * @author eric.hao
 * @since 2024/10/08
 */
@Slf4j
@Service
@UnicomTag(InvokeTag.TAG_GENERAL)
@RequiredArgsConstructor
public class ProducerProxyService implements ProducerProxy {

    private final RosefinchInstanceService instanceService;
    private final QueueHandlerService handlerService;

    @Override
    public Long send(TaskMessage payload, String runType) {
        // 初始化任务链路ID
        RosefinchTraceUtil.initTraceId();
        // 初始化任务日志
        var instance = instanceLog(payload, runType);
        payload.setInstanceDTO(RosefinchConfigConvert.INSTANCE.saveParamToDTO(instance));
        // 生产者：发布报文消息
        handlerService.publish(payload);
        // 销毁任务链路ID
        RosefinchTraceUtil.clearTraceId();
        return instance.getId();
    }

    @Override
    public boolean stop(String taskCode, long instanceId) {
        try {
            LogUtil.info(taskCode, null, "[ROSEFINCH] 终止任务...", null, null);
            // 立即终止
            boolean stopTag = handlerService.stopImmediately(instanceKey(instanceId));
            // 更新执行结果
            var saveParam = new RosefinchInstanceSaveParamVO();
            saveParam.setId(instanceId);
            saveParam.setEndTime(LocalDateTime.now());
            if (stopTag) {
                saveParam.setInstanceStatus(InstanceStatus.STOP.getCode());
            }
            saveParam.setRemark("手动终止：" + SuccessTag.fromCode(stopTag));
            instanceService.update(saveParam);
            LogUtil.info(taskCode, null, "[ROSEFINCH] 终止任务：" + SuccessTag.fromCode(stopTag), null, null);
            return stopTag;
        } catch (Exception e) {
            logger.error("[ROSEFINCH] 终止任务异常：", e);
            LogUtil.error("[ROSEFINCH] 终止任务异常：", e);
            // 终止异常，按失败返回
            return false;
        }
    }

    /**
     * 实例日志初始化
     *
     * @param payload 消息报文
     * @param runType 执行方式
     * @return 任务实例
     */
    private RosefinchInstanceSaveParamVO instanceLog(TaskMessage payload, String runType) {
        var saveParam = new RosefinchInstanceSaveParamVO();
        saveParam.setMasId(payload.getTaskId());
        saveParam.setTaskName(payload.getTaskName());
        saveParam.setTaskCode(payload.getTaskCode());
        saveParam.setRunType(runType);
        saveParam.setInstanceStatus(InstanceStatus.READY.getCode());
        saveParam.setStartTime(LocalDateTime.now());
        saveParam.setGlobalTraceId(TracerUtils.getTraceId());
        saveParam.setTraceId(RosefinchTraceUtil.getTraceId());
        saveParam.setMethodArgs(BeanUtils.toJsonOrEmpty(payload.getPayload()));
        // 批处理任务
        if (RosefinchType.BATCH.getCode().compareTo(payload.getTaskType()) == 0) {
            saveParam.setTotalCount(payload.size());
            saveParam.setSuccessCount(0);
            saveParam.setFailCount(0);
        }
        Long instanceId = instanceService.save(saveParam);
        saveParam.setId(instanceId);
        return saveParam;
    }
}
